#
# spec file for package libsmraw
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

Name:           libsmraw
%define lname	libsmraw1
Version:        20231127
Release:        1.1
Summary:        Library and tools to access the (split) RAW image format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libsmraw
Source:         https://github.com/libyal/libsmraw/releases/download/%version/libsmraw-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libsmraw/releases/download/%version/libsmraw-alpha-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfcache) >= 20230115
BuildRequires:  pkgconfig(libfdata) >= 20230319
BuildRequires:  pkgconfig(libfvalue) >= 20220120
BuildRequires:  pkgconfig(libhmac) >= 20231127
BuildRequires:  pkgconfig(libuna) >= 20230710
BuildRequires:  pkgconfig(openssl) >= 1.0
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libsmraw is a library to access the storage media RAW format.
The library supports both RAW and split RAW.

%package -n %lname
Summary:        Library and tools to access the (split) RAW image format
Group:          System/Libraries

%description -n %lname
libsmraw is a library to access the storage media RAW format.
The library supports both RAW and split RAW.

%package devel
Summary:        Development files for libsmraw, a (split) RAW image file library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libsmraw is a library to access the storage media RAW format.

This subpackage contains libraries and header files for developing
applications that want to make use of libsmraw.

%package tools
Summary:        Utilities for reading and writing storage media (split) RAW files
Group:          Productivity/File utilities

%description tools
This subpackage contains the utility programs from libsmraw to
acquire, export, query and verify storage media (split) RAW files.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libsmraw.so.1*

%files -n %name-devel
%license COPYING
%_includedir/libsmraw*
%_libdir/libsmraw.so
%_libdir/pkgconfig/libsmraw.pc
%_mandir/man3/libsmraw.3*

%files -n %name-tools
%license COPYING
%_bindir/smrawverify
%_bindir/smrawmount
%_mandir/man1/smrawmount.1*

%files %python_files
%license COPYING
%python_sitearch/pysmraw.so

%changelog
* Mon Nov 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231127
  * Improvded Python Unicde handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Fri Mar 24 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230320
  * No changelog
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Sat Oct 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221028
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables Python2 on Leap 15.)
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210817
  * Python binding updates
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Remove unused BuildRequire on python2.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210418 (ad75680d)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 17 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201210
  * worked on python binding
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Wed Apr 17 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181227
  * Added smraw.net.rc
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libsmraw to python2-libsmraw as expected by singlespec
- remove Provides pysmraw as it is not versioned
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170803
  * applied 2017 update
  * worked on tests
- change Group: field for python binding to devel/languages/python
- Add python3 binding subpackage
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20160424
  * bug fix for information file
  * changes for Python 3 support
  * Changes to Python bindings
  * fixes for rpmbuild
  * removed read/write random
  * updated dependencies
  * worked on tests
- clean-up BuildRequires
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * worked on multi-threading support
  * code clean up
  * bug fixes for information file
  * bug fix in Python-bindings
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using more packages from OBS, not internal version
- remove %%if opensuse logic.  Not needed now libyal is in security:forensics
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 20140817
  * Worked on smrawmount
- updated Source: field to have fullpath; removed DL_URL field
* Fri Aug 22 2014 Greg.Freemyer@gmail.com
- update BuildRequires to use as many external packages as possible
- add Provides: pysmraw to python sub-project to match upstream requires
- add %%doc to all sub-projects
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to 0~20140728
  * removed examples
  * worked on Python bindings
  * smrawmount worked on Dokan support
  * added smrawverify
  * worked on tests
  - replaced compare test by smrawverify test
  * smrawmount added -X option
  * updated dependencies
  * textual changes
  * changes due to libmfdata and libfdata merge
- use internal version of libhmac, external version is causing build errors
* Fri Aug  2 2013 Greg.Freemyer@gmail.com
- update DL-URL
- clean up BuildRequires a little bit
* Mon Apr 22 2013 Greg.Freemyer@gmail.com
- Re-organize BuildRequires and add comments about why many are commented out
* Fri Apr  5 2013 jengelh@inai.de
- Initial package (version 0~20130402) for build.opensuse.org
